import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:kursach/components/l10n/app_locale.dart';
import 'package:kursach/data/repositories/hiphop_repository.dart';
import 'package:kursach/presentation/other/like_bloc/like_bloc.dart';
import 'package:kursach/presentation/other/locale_bloc/locale_bloc.dart';
import 'package:kursach/presentation/other/locale_bloc/locale_state.dart';
import 'package:kursach/presentation/pages/home_page/home_page.dart';
import 'package:kursach/presentation/pages/home_page/bloc/bloc.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider<LocaleBloc>(
      lazy: false,
      create: (context) => LocaleBloc(Locale(Platform.localeName)),
      child: BlocBuilder<LocaleBloc, LocaleState>(
        builder: (context, state) {
          return MaterialApp(
            title: 'HipHop',
            debugShowCheckedModeBanner: false,
            localizationsDelegates: AppLocale.localizationsDelegates,
            supportedLocales: AppLocale.supportedLocales,
            locale: state.currentLocale,
            theme: ThemeData(
              colorScheme: ColorScheme.fromSeed(seedColor: Colors.white),
              useMaterial3: true,
            ),
            home: RepositoryProvider<HipHopRepository>(
              lazy: true,
              create: (_) => HipHopRepository(),
              child: BlocProvider<LikeBloc>(
                lazy: false,
                create: (context) => LikeBloc(),
                child: BlocProvider<HomeBloc>(
                  lazy: false,
                  create: (context) => HomeBloc(context.read<HipHopRepository>()),
                  child: const MyHomePage(title: 'Kursach'),
                ),
              ),
            ),
          );
        },
      ),
    );
  }
}
